""" all constants for the core_main_registry_app
"""


class DataStatus(object):
    ACTIVE = "active"
    INACTIVE = "inactive"
    DELETED = "deleted"
